@@ -159,13 +159,13 @@ def profile_active_command(ctx, profile_name):
     cls=HelpColorsCommand,
     help_options_color='blue'
 )
-@click.option('--key', '-k', type=str, help='Encode config with a key')
+@click.option('--plain', is_flag=True, help='Export the config non-Base64 encoded.')
 @click.argument('profile-name', type=str, required=False, nargs=1)
 @click.pass_context
-def profile_export_command(ctx, key, profile_name):
+def profile_export_command(ctx, plain, profile_name):
     """Create a new config file from a profile."""
     Profile(cli=ctx.obj["cli"]).export_config(
-        key=key,
+        plain=plain,
         profile_name=profile_name
     )
 
@@ -175,20 +175,17 @@ def profile_export_command(ctx, key, profile_name):
     cls=HelpColorsCommand,
     help_options_color='blue'
 )
-@click.option('--key', '-k', type=str, required=True, help='Decode config with a key.')
 @click.option('--output-file', '-f', type=str, required=False,
-              help='Save the import config to a specific file location.')
-@click.argument('enc-config', type=str, required=True, nargs=1)
+              help='Create the config in a specific file location.')
+@click.argument('config-base64', type=str, required=True, nargs=1)
 @click.pass_context
-def profile_import_command(ctx, key, output_file, enc_config):
+def profile_import_command(ctx, output_file, config_base64):
     """Import an encrypted config file."""
     Profile(cli=ctx.obj["cli"]).import_config(
-        key=key,
         file=output_file,
-        enc_config=enc_config
+        config_base64=config_base64
     )
 
-
 profile_command.add_command(profile_init_command)
 profile_command.add_command(profile_list_command)
 profile_command.add_command(profile_active_command)
@@ -237,22 +234,34 @@ def secret_list_command(ctx, uid, json):
     cls=HelpColorsCommand,
     help_options_color='blue'
 )
-@click.option('--uid', '-u', required=True, type=str, multiple=True)
+@click.option('--uid', '-u', type=str, multiple=True, help='Unique identifier of record.')
+@click.option('--title', '-t', type=str, multiple=True, help='Title of record.')
+@click.option('--field', '-f', type=str, help='Field to get.')
 @click.option('--query', '-q', type=str, help='Perform a JSONPath query on results.')
 @click.option('--json', is_flag=True, help='Return secret as JSON')
 @click.option('--raw', is_flag=True, help="Remove quotes on return quote text.")
 @click.option('--force-array', is_flag=True, help="Return secrets as array even if a single record.")
 @click.option('--unmask', is_flag=True, help="Show password like values in table views.")
 @click.pass_context
-def secret_get_command(ctx, uid, query, json, raw, force_array, unmask):
+def secret_get_command(ctx, uid, title, field, query, json, raw, force_array, unmask):
     """Get secret record(s)."""
 
     output = "text"
     if json is True:
         output = "json"
 
+    total_query = len(uid) + len(title)
+
+    if total_query == 0:
+        sys.exit("No uid or title specified for secret get command.")
+
+    if total_query > 1 and field is not None:
+        sys.exit("Cannot perform field search on multiple records. Only choose one uid/title.")
+
     ctx.obj["secret"].query(
         uids=uid,
+        titles=title,
+        field=field,
         jsonpath_query=query,
         output_format=output,
         raw=raw,
